﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using ATOUCHX;

namespace atouch_p09_cz_02
{
    public partial class Form1 : Form
    {
        //Vytvoření delegátů pro komunikaci mezi vlákny
        private delegate void DelEndPutData(int WID, int Result, int Param);
        private delegate void DelEndGetData(int WID, int Result, int Param, object DATA);

        //Nutná definice objektů a proměnných.
        AtouchApp App = new AtouchApp();
        int Err;
        Object Data = new Object();

        public Form1()
        {
            InitializeComponent();
            //Inicializace návratových událostí komunikace. Po napsání App.xxx += a dvojím 
            //stisku klávesy Tab se automaticky vytvoří obslužná těla událostí.
            App.EndNetGetData += new _IAtouchAppEvents_EndNetGetDataEventHandler(App_EndNetGetData);
            App.EndNetPutData += new _IAtouchAppEvents_EndNetPutDataEventHandler(App_EndNetPutData);
        }

        void App_EndNetPutData(int WID, int Result, int Param)
        {
            if (this.InvokeRequired)
            {
                //Kód je spuštěn v jiném vlákně, než které zabezpečuje vykreslování okna, proto 
                //je potřeba pomocí příkazu invoke spustit kód pro práci s oknem do vykreslovacího vlákna.
                this.Invoke(new DelEndPutData(App_EndNetPutData), new Object[] { WID, Result, Param });
                return;
            }
            //Zde již kód běží ve vykreslovacím vlákně a je možné ovlivňovat zobrazovací prvky
            //Zápis na formulář po zpracování požadavku na zápis proměnné.
            if ((Result & (Int16)AtouchX_Communication_State.atfOk) != 0)
            {   //Komunikace skončila OK.
                ComText.Text = "OK";
            }
            else
            {   //Komunikace skončila chybou. 
                ComText.Text = Result.ToString();
            }
        }

        void App_EndNetGetData(int WID, int Result, int Param, object DATA)
        {
            if (this.InvokeRequired)
            {
                //Kód je spuštěn v jiném vlákně, než které zabezpečuje vykreslování okna, proto 
                //je potřeba pomocí příkazu invoke spustit kód pro práci s oknem do vykreslovacího vlákna.
                this.Invoke(new DelEndGetData(App_EndNetGetData), new Object[] { WID, Result, Param, DATA });
                return;
            }
            //Zde již kód běží ve vykreslovacím vlákně a je možné ovlivňovat zobrazovací prvky
            //Zápis na formulář po zpracování požadavku na čtení proměnné.
            if ((Result & (Int16)AtouchX_Communication_State.atfOk) != 0)
            {   //Komunikace skončila OK.
                ComText.Text = "OK";
                switch (Param)
                {
                    case 1:
                        ReadInt.Text = DATA.ToString();
                        break;
                    case 2:
                        ReadLon.Text = DATA.ToString();
                        break;
                    case 3:
                        ReadFlo.Text = DATA.ToString();
                        break;
                }
            }
            else
            {   //Komunikace skončila chybou.
                ComText.Text = Result.ToString();
            }
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            //Inicializační metoda pro komunikaci přes síť DB-Net.
            App.VariantOnly = false;
            Err = App.InitFromFile("hw.ini", "db.ini");
            ErrText.Text = Err.ToString();
        }

        //Ukončení komunikace se sítí DB-Net.
        private void EndProg_Click(object sender, EventArgs e)
        {
            App.Done();
            this.Close();
        }

        //Načítání proměnných z ŘS: posílá se WID a identifikační parametr
        private void ButReadInt_Click(object sender, EventArgs e)
        {
            Err = App.NetGetData(1001, 1);
            ErrText.Text = Err.ToString();
        }

        private void ButReadLon_Click(object sender, EventArgs e)
        {
            Err = App.NetGetData(1003, 2);
            ErrText.Text = Err.ToString();
        }

        private void ButReadFlo_Click(object sender, EventArgs e)
        {
            Err = App.NetGetData(1005, 3);
            ErrText.Text = Err.ToString();
        }

        //Ukládání proměnných do ŘS: posílá se WID, identifikační parametr a nová hodnota.
        private void ButWriteInt_Click(object sender, EventArgs e)
        {
            Data = Convert.ToInt16(WriteInt.Text);
            //Typ Int v ŘS má délku 2B, proto zadanou hodnotu konvertujeme na C# typ Int16.
            Err = App.NetPutData(1001, 1, Data);
        }

        private void ButWriteLon_Click(object sender, EventArgs e)
        {
            Data = Convert.ToInt32(WriteLon.Text);
            Err = App.NetPutData(1003, 2, Data);
        }

        private void ButWriteFlo_Click(object sender, EventArgs e)
        {
            Data = Convert.ToSingle(WriteFlo.Text);
            Err = App.NetPutData(1005, 3, Data);
        }
    }
}
