﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using ATOUCHX;

namespace atouch_p10_cz_02
{
    public partial class Form1 : Form
    {
        //Vytvoření delegátů pro komunikaci mezi vlákny
        private delegate void DelEndPutData(int WID, int Result, int Param);
        private delegate void DelEndGetData(int WID, int Result, int Param, object DATA);

        //Nutná definice objektů a proměnných.
        AtouchApp App = new AtouchApp();
        int Err;

        public Form1()
        {
            InitializeComponent();
            //Inicializace návratových událostí komunikace. Po napsání App.xxx += a dvojím 
            //stisku klávesy Tab se automaticky vytvoří obslužná těla událostí.
            App.EndNetGetData += new _IAtouchAppEvents_EndNetGetDataEventHandler(App_EndNetGetData);
            App.EndNetPutData += new _IAtouchAppEvents_EndNetPutDataEventHandler(App_EndNetPutData);
        }

        void App_EndNetPutData(int WID, int Result, int Param)
        {
            if (this.InvokeRequired)
            {
                //Kód je spuštěn v jiném vlákně, než které zabezpečuje vykreslování okna, proto 
                //je potřeba pomocí příkazu invoke spustit kód pro práci s oknem do vykreslovacího vlákna.
                this.Invoke(new DelEndPutData(App_EndNetPutData), new Object[] { WID, Result, Param });
                return;
            }
            //Zde již kód běží ve vykreslovacím vlákně a je možné ovlivňovat zobrazovací prvky
            //Zápis na formulář po zpracování požadavku na zápis matice.
            if ((Result & (Int16)AtouchX_Communication_State.atfOk) != 0)
            {   //Komunikace skončila OK.
                ComText.Text = "OK";
            }
            else
            {   //Komunikace skončila chybou. 
                ComText.Text = Result.ToString();
            }
        }

        void App_EndNetGetData(int WID, int Result, int Param, object DATA)
        {
            if (this.InvokeRequired)
            {
                //Kód je spuštěn v jiném vlákně, než které zabezpečuje vykreslování okna, proto 
                //je potřeba pomocí příkazu invoke spustit kód pro práci s oknem do vykreslovacího vlákna.
                this.Invoke(new DelEndGetData(App_EndNetGetData), new Object[] { WID, Result, Param, DATA });
                return;
            }
            //Zde již kód běží ve vykreslovacím vlákně a je možné ovlivňovat zobrazovací prvky
            //Zápis na formulář po zpracování požadavku na čtení matice.
            if ((Result & (Int16)AtouchX_Communication_State.atfOk) != 0)
            {   //Komunikace skončila OK.
                ComText.Text = "OK";
                switch (Param)
                {
                    case 1:
                        Int16[,] iarr = (Int16[,])DATA;
                        M11IW.Text = iarr[0, 0].ToString();
                        M12IW.Text = iarr[0, 1].ToString();
                        M13IW.Text = iarr[0, 2].ToString();
                        M14IW.Text = iarr[0, 3].ToString();
                        M15IW.Text = iarr[0, 4].ToString();
                        break;
                    case 2:
                        Int32[,] larr = (Int32[,])DATA;
                        M11LW.Text = larr[0, 0].ToString();
                        M12LW.Text = larr[0, 1].ToString();
                        M21LW.Text = larr[1, 0].ToString();
                        M22LW.Text = larr[1, 0].ToString();
                        break;
                    case 3:
                        Single[,] farr = (Single[,])DATA;
                        M11FW.Text = farr[0, 0].ToString();
                        M21FW.Text = farr[1, 0].ToString();
                        M31FW.Text = farr[2, 0].ToString();
                        M41FW.Text = farr[3, 0].ToString();
                        break;
                }
            }
            else
            {   //Komunikace skončila chybou.
                ComText.Text = Result.ToString();
            }
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            //Inicializační metoda pro komunikaci přes síť DB-Net.
            Err = App.InitFromFile("hw.ini", "db.ini");
            App.VariantOnly = false;
            ErrText.Text = Err.ToString();
        }

        //Ukončení komunikace se sítí DB-Net.
        private void EndProg_Click(object sender, EventArgs e)
        {
            App.Done();
            this.Close();
        }

        //Načítání matic z ŘS
        private void ReadIntMX_Click(object sender, EventArgs e)
        {
            Err = App.NetGetDataMtx(1002, 0, 0, 1, 5, 1);
            ErrText.Text = Err.ToString();
        }

        private void ReadLonMX_Click(object sender, EventArgs e)
        {
            Err = App.NetGetDataMtx(1004, 0, 0, 2, 2, 2);
            ErrText.Text = Err.ToString();
        }

        private void ReadFloMX_Click(object sender, EventArgs e)
        {
            Err = App.NetGetDataMtx(1006, 0, 0, 4, 1, 3);
            ErrText.Text = Err.ToString();
        }

        //Zápis matic do ŘS
        private void WriteIntMX_Click(object sender, EventArgs e)
        {   //Typ Int v ŘS má délku 2B, proto zadanou hodnotu konvertujeme na C# typ Int16.
            object[,] Data = new object[1, 5];
            Data[0, 0] = Convert.ToInt16(M11I.Text);
            Data[0, 1] = Convert.ToInt16(M12I.Text);
            Data[0, 2] = Convert.ToInt16(M13I.Text);
            Data[0, 3] = Convert.ToInt16(M14I.Text);
            Data[0, 4] = Convert.ToInt16(M15I.Text);
            Err = App.NetPutDataMtx(1002, 0, 0, 1, 5, 1, Data);
            ErrText.Text = Err.ToString();
        }

        private void WriteLonMX_Click(object sender, EventArgs e)
        {
            object[,] Data = new object[2, 2];
            Data[0, 0] = Convert.ToInt32(M11L.Text);
            Data[0, 1] = Convert.ToInt32(M12L.Text);
            Data[1, 0] = Convert.ToInt32(M21L.Text);
            Data[1, 1] = Convert.ToInt32(M22L.Text);
            Err = App.NetPutDataMtx(1004, 0, 0, 2, 2, 2, Data);
            ErrText.Text = Err.ToString();
        }

        private void WriteFloMX_Click(object sender, EventArgs e)
        {
            object[,] Data = new object[4, 1];
            Data[0, 0] = Convert.ToSingle(M11F.Text);
            Data[1, 0] = Convert.ToSingle(M21F.Text);
            Data[2, 0] = Convert.ToSingle(M31F.Text);
            Data[3, 0] = Convert.ToSingle(M41F.Text);
            Err = App.NetPutDataMtx(1006, 0, 0, 4, 1, 3, Data);
            ErrText.Text = Err.ToString();
        }
    }
}
