﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using ATOUCHX;

namespace atouch_p11_cz_02
{
    public partial class Form1 : Form
    {
        //Vytvoření delegátů pro komunikaci mezi vlákny
        private delegate void DelEndPutData(short Station, int Result, int Param);
        private delegate void DelEndGetData(short Station, int Result, int Param, DateTime Date);

        //Nutná definice objektů a proměnných.
        AtouchApp App = new AtouchApp();
        int Err;

        public Form1()
        {
            InitializeComponent();
            //Inicializace návratových událostí komunikace. Po napsání App.xxx += a dvojím 
            //stisku klávesy Tab se automaticky vytvoří obslužná těla událostí.
            App.EndNetGetTime += new _IAtouchAppEvents_EndNetGetTimeEventHandler(App_EndNetGetTime);
            App.EndNetPutTime += new _IAtouchAppEvents_EndNetPutTimeEventHandler(App_EndNetPutTime);
        }

        void App_EndNetPutTime(short Station, int Result, int Param)
        {
            if (this.InvokeRequired)
            {
                //Kód je spuštěn v jiném vlákně, než které zabezpečuje vykreslování okna, proto 
                //je potřeba pomocí příkazu invoke spustit kód pro práci s oknem do vykreslovacího vlákna.
                this.Invoke(new DelEndPutData(App_EndNetPutTime), new Object[] { Station, Result, Param });
                return;
            }
            //Zde již kód běží ve vykreslovacím vlákně a je možné ovlivňovat zobrazovací prvky
            //Zápis na formulář po zpracování požadavku na zápis proměnné.
            if ((Result & (Int16)AtouchX_Communication_State.atfOk) != 0)
            {   //Komunikace skončila OK.
                ComText.Text = "OK";
            }
            else
            {   //Komunikace skončila chybou. 
                ComText.Text = Result.ToString();
            }
        }

        void App_EndNetGetTime(short Station, int Result, int Param, DateTime DateTime)
        {
            if (this.InvokeRequired)
            {
                //Kód je spuštěn v jiném vlákně, než které zabezpečuje vykreslování okna, proto 
                //je potřeba pomocí příkazu invoke spustit kód pro práci s oknem do vykreslovacího vlákna.
                this.Invoke(new DelEndGetData(App_EndNetGetTime), new Object[] { Station, Result, Param, DateTime });
                return;
            }
            //Zápis na formulář po zpracování požadavku na čtení proměnné.
            //Zde již kód běží ve vykreslovacím vlákně a je možné ovlivňovat zobrazovací prvky
            if ((Result & (Int16)AtouchX_Communication_State.atfOk) != 0)
            {   //Komunikace skončila OK.
                ComText.Text = "OK";
                DTDT.Text = DateTime.ToString();
            }
            else
            {   //Komunikace skončila chybou.
                ComText.Text = Result.ToString();
            }
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            //Inicializační metoda pro komunikaci přes síť DB-Net.
            Err = App.InitFromFile("hw.ini", "db.ini");
            App.VariantOnly = false;
            ErrText.Text = Err.ToString();
        }

        //Ukončení komunikace se sítí DB-Net.
        private void EndProg_Click(object sender, EventArgs e)
        {
            App.Done();
            this.Close();
        }

        //Čtení času z ŘS
        private void ReadTime_Click(object sender, EventArgs e)
        {
            Err = App.NetGetTime(1, 1);
            ErrText.Text = Err.ToString();
        }

        private void DefaultDT_Click(object sender, EventArgs e)
        {
            TextWrTiDate.Text = "1.1.1980 0:00:01";
        }

        //Zápis času do ŘS
        private void WriteTimeDate_Click(object sender, EventArgs e)
        {
            DateTime DTMy;
            string DTString = TextWrTiDate.Text;
            if (TextWrTiDate.Text != "")
            {
                DTMy = Convert.ToDateTime(DTString);
                Err = App.NetPutTime(1, 1, DTMy);
                ErrText.Text = Err.ToString();
            }
        }

        //Zápis synchronizovaného času do ŘS
        private void SyncPC_Click(object sender, EventArgs e)
        {
            DateTime DTMy = new DateTime(1980, 1, 1);
            Err = App.NetPutTime(1, 1, DTMy);
            ErrText.Text = Err.ToString();
        }
    }
}
